@@ -4,13 +4,17 @@
 
 =head1 SYNOPSIS
 
-WebService::GoogleHack - Is a Perl package that interacts with the Google API, and has some basic functionalities 
-that allow the user to interact with Google and retrieve results. It also has some Natural Language 
-Processing capabilities, such as the ability to predict the sematic orienation of words etc.
+WebService::GoogleHack - Is a Perl package that interacts with the Google API,
+and has some basic functionalities that allow the user to interact with 
+Googleand retrieve results. It also  has some Natural Language Processing 
+capabilities, such as the ability to predict the semantic orienation of words, 
+build word clusters, find words that are common to a pair of words etc.
 
 =head1 DESCRIPTION
 
-This module acts as a driver module. Basically it acts as an interface between the user and the modules. The modules that are controlled by WebService::GoogleHack is:
+This module acts as a driver module. Basically it acts as an interface between
+the user and the modules. The modules that are controlled by 
+WebService::GoogleHack are:
 
 WebService::GoogleHack::Text, Search, Rate, Spelling
 
@@ -59,7 +63,7 @@ it under the same terms as Perl itself.
 
 package WebService::GoogleHack;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use SOAP::Lite;
 use Set::Scalar;
@@ -107,9 +111,6 @@ $this-> {'safeSearch'} ="false";
 $this-> {'lr'} ="";
 $this-> {'oe'} ="";
 $this-> {'ie'} ="";
-$this-> {'NumResults'} = undef;
-$this-> {'snippet'} = undef;
-$this-> {'searchTime'} = undef;
 $this-> {'url'} = undef;
 $this-> {'cachedPage'} = undef;
 $this-> {'title'} = undef;
@@ -625,14 +626,13 @@ sub Search
  
   $results=WebService::GoogleHack::Search::searchPhrase($this, $searchString,$num_results);
 
- # print "\n Printing here ";
- # print $results->{'snippet'}->[0];
- 
   $this->{'NumResults'}=$results->{'NumResults'};
   $this-> {'snippet'} = $results->{'snippet'};
   $this-> {'searchTime'} =$results->{'searchTime'};
-  
- return $this;
+  $this-> {'url'} = $results->{'url'};
+  $this-> {'title'} = $results->{'title'};
+ 
+  return $this;
 
 }
 
@@ -640,7 +640,8 @@ sub Search
 
 =head2 __PACKAGE__->initConfig(\%args)
 
-Purpose:  this function is used to read a configuration file containing informaiton such as the Google-API key, the words list etc.
+Purpose:  this function is used to read a configuration file containing 
+informaiton such as the Google-API key, the words list etc.
 
 
 Valid arguments are :
@@ -687,7 +688,8 @@ return $this;
 
 =head2 __PACKAGE__->printConfig(\%args)
 
-Purpose:  This function is used to print the information read from a configuration file 
+Purpose:  This function is used to print the information read from a 
+configuration file 
 
 No arguments.
 
@@ -728,7 +730,8 @@ sub printConfig
 
 =head2 __PACKAGE__->getSearchSnippetWords(\%args)
 
-Purpose:  Given a search word, this function tries to retreive the text surrounding the search word in the retrieved snippets. 
+Purpose:  Given a search word, this function tries to retreive the text 
+surrounding the search word in the retrieved snippets. 
 
 Valid arguments are :
 
@@ -740,13 +743,26 @@ B<searchString>
 
 I<string>.  The search string which can be a word or phrase
 
+=item *
+
+B<numResults> 
+
+I<string>. The number of results to be processed from google.
+
+
+=item *
+
+B<trace_file>.
+
+I<string>.   The location of the trace file. If a file_name is given, the results are stored in this file
+
 
 =item *
 
 B<proximity> 
 
-I<string>. The number of words surrounding the searchString (Not Implemented yet 
-
+I<string>. The number of words surrounding the searchString (Not Implemented 
+yet 
 
 =back
 
@@ -761,13 +777,17 @@ sub getSearchSnippetWords
 
     my  $searchInfo = shift;
     my  $searchString = shift;
-    my $proximity = shift;
-    my $trace_file=shift;
-
+    my  $numResults = shift;
+    my  $trace_file=shift;
+    my  $proximity = shift;
     require WebService::GoogleHack::Search;
 
-    $results=WebService::GoogleHack::Search::searchPhrase($searchInfo, $searchString);
+    $results=WebService::GoogleHack::Search::searchPhrase($searchInfo, $searchString,$numResults);
 
+    if(!defined($numResults))
+    {
+	$numResults=10;
+    }
 
     @strings=();
     $count=0;
@@ -776,7 +796,7 @@ sub getSearchSnippetWords
 # I am just checking the first 10 snippets since the snippets get more irrelevant as
 # the hit number increases
 
-    while( $count < 10)
+    while( $count < $numResults)
     {
 # removing html tags from the resulting snippet
 
@@ -814,7 +834,10 @@ close(DAT);
 
 =head2 __PACKAGE__->getCachedSurroundingWords(\%args)
 
-  Purpose:  Given a search word, this function tries to retreive the text surrounding the search word in the retrieved CACHED Web pages. It basically does the search and passes the search results to the WebService::GoogleHack::Text::getCachedSurroundingWords function.
+  Purpose:  Given a search word, this function tries to retreive the text 
+surrounding the search word in the retrieved CACHED Web pages. It basically 
+does the search and passes the search results to the 
+WebService::GoogleHack::Text::getCachedSurroundingWords function.
 
 Valid arguments are :
 
@@ -927,7 +950,10 @@ sub getCachedSurroundingWords
 
 =head2 __PACKAGE__->getSearchSnippetSentences(\%args)
 
-  Purpose:  Given a search word, this function tries to retreive the sentences in the snippet.It basically does the search and passes the search results to the WebService::GoogleHack::Text::getSnippetSentences function
+  Purpose:  Given a search word, this function tries to retreive the 
+sentences in the snippet.It basically does the search and passes the 
+search results to the WebService::GoogleHack::Text::getSnippetSentences 
+function
 
 
 Valid arguments are :
@@ -1007,7 +1033,8 @@ sub getSnippetSentences
 
 =head2 __PACKAGE__->getCachedSurroundingSentences(\%args)
 
-  Purpose:  Given a search word, this function tries to retreive the sentences in the cached web page.
+  Purpose:  Given a search word, this function tries to retreive the 
+sentences in the cached web page.
 
 Valid arguments are :
 
@@ -1023,11 +1050,13 @@ I<string>.  The search string which can be a word or phrase
 
 B<trace_file>.
 
-I<string>.   The location of the trace file. If a file_name is given, the results are stored in this file
+I<string>.   The location of the trace file. If a file_name is given, 
+the results are stored in this file
 
 =back
 
-returns : Returns a hash which contains the parsed sentences as values and the key being the web URL.
+returns : Returns a hash which contains the parsed sentences as values and the
+key being the web URL.
 
 =cut
 
@@ -1065,7 +1094,8 @@ sub getCachedSurroundingSentences
 
 =head2 __PACKAGE__->getSearchCommonWords(\%args)
 
-  Purpose:Given two search words, this function tries to retreive the common text/words surrounding the search strings in the retrieved snippets.
+  Purpose:Given two search words, this function tries to retreive the common 
+text/words surrounding the search strings in the retrieved snippets.
 
 Valid arguments are :
 
@@ -1088,11 +1118,19 @@ I<string>.  The search string which can be a word or phrase
 
 B<trace_file>.
 
-I<string>.   The location of the trace file. If a file_name is given, the results are stored in this file
+I<string>.   The location of the trace file. If a file_name is given, the 
+results are stored in this file
+
+=item *
+
+B<stemmer>.
+
+I<bool>. Porter Stemmer on or off.
 
 =back
 
-returns : Returns a hash which contains the parsed sentences as values and the key being the web URL.
+returns : Returns a hash which contains the parsed sentences as values and the
+ key being the web URL.
 
 =cut
 
@@ -1104,12 +1142,26 @@ sub getSearchCommonWords
     my  $searchInfo = shift;
     my  $searchString1 = shift;  
     my  $searchString2 = shift;
-    my $trace_file=shift;
+    my  $numResults=shift;
+    my  $trace_file=shift;
+    my $stemmer=shift;
 
+
+    if(!defined($numResults))
+    {
+	$numResults=10;
+    }
+
+    if(!defined($stemmer))
+    {
+	$stemmer=false;
+    }
+
+ #   print $trace_file;
     require WebService::GoogleHack::Search;
 
     print "\n\nOne $searchString1, Two $searchString2";
-    $results1=WebService::GoogleHack::Search::searchPhrase($searchInfo, $searchString1)
+    $results1=WebService::GoogleHack::Search::searchPhrase($searchInfo, $searchString1, $numResults)
 ;
     @strings1=(); 
 
@@ -1117,7 +1169,7 @@ sub getSearchCommonWords
 
     require WebService::GoogleHack::Text;
      $innc=0;
-    while( $count < 10)
+    while( $count < $numResults)
     {
 	#print "here";
 	#print $results1->{'snippet'}->[$count];
@@ -1130,7 +1182,7 @@ sub getSearchCommonWords
     }
     
     
-    $results2=WebService::GoogleHack::Search::searchPhrase($searchInfo, $searchString2);
+    $results2=WebService::GoogleHack::Search::searchPhrase($searchInfo, $searchString2, $numResults);
     @strings2=(); 
     $count=0;
     
@@ -1139,8 +1191,9 @@ sub getSearchCommonWords
 # I am just checking the first 10 snippets since the snippets get more irrelevant as the hit number increases
     $innc=0;
    
-    while( $count < 10)
+    while( $count < $numResults)
     {
+
 # removing html tags from the resulting snippet
 if($results2->{'snippet'}->[$count] ne "")
    {
@@ -1154,7 +1207,7 @@ if($results2->{'snippet'}->[$count] ne "")
     $count=0;
 
 
-%results_final1=WebService::GoogleHack::Text::getSurroundingWords($searchString1,5 , @strings1);
+%results_final1=WebService::GoogleHack::Text::getSurroundingWords($searchString1,5 , @strings1, $stemmer);
 
 
 
@@ -1164,10 +1217,18 @@ if($results2->{'snippet'}->[$count] ne "")
 while( ($Key, $Value) = each(%results_final1) ){
 
     $temp_string=""; 
+
+if($stemmer eq "true")
+{
     @stem = Text::English::stem( "$Key" );
     print "\n This is the stem for $Key:$stem[0]\n";;
     $temp_string=$stem[0];
-  
+}
+else
+{
+    $temp_string="$Key"; 
+}
+ 
 	$sequence_occs{"$temp_string"}++ if exists $sequence_occs{"$temp_string"};
 	
 #else if the sequence does not in the array, then insert it into the array
@@ -1181,18 +1242,24 @@ while( ($Key, $Value) = each(%results_final1) ){
 
 
 
-%results_final2=WebService::GoogleHack::Text::getSurroundingWords($searchString2,5 , @strings2);
+%results_final2=WebService::GoogleHack::Text::getSurroundingWords($searchString2,5 , @strings2, $stemmer);
 
 
 while( ($Key, $Value) = each(%results_final2) ){
 
     $temp_string="";
+if($stemmer eq "true")
+{
     @stem = Text::English::stem( "$Key" );
-
-
     $temp_string=$stem[0];
+}
+else
+{
+    $temp_string="$Key";
 
-   $sequence_occs{"$temp_string"}++ if exists $sequence_occs{"$temp_string"};
+}
+
+$sequence_occs{"$temp_string"}++ if exists $sequence_occs{"$temp_string"};
 
 #else if the sequence does not in the array, then insert it into the array
  
@@ -1229,8 +1296,11 @@ while( ($Key, $Value) = each(%results_final2) ){
 	}
 
 
-    $fileContent="\n Intersecting Words for $searchString1 & $searchString2\n\n";
+$date=getDateHeader();
 
+$fileContent="\n\n\n================================================================";
+$fileContent.="\n\n Query Date - $date - Intersecting Words for $searchString1 & $searchString2\n\n";
+$fileContent.="================================================================\n\n";
     $fileContent.="\nWord List for $searchString1\n";
     $fileContent.="=================================\n";
     
@@ -1278,7 +1348,9 @@ return %sequence_occs;
 
 =head2 __PACKAGE__->getWordClusters(\%args)
 
-  Purpose:Given a search string, this function retreive the top frequency words, and does a search on those words, and builds a list of words that can be regarded as a cluster of related words.
+  Purpose:Given a search string, this function retreive the top frequency words
+, and does a search on those words, and builds a list of words that can be 
+regarded as a cluster of related words.
 
 Valid arguments are :
 
@@ -1294,16 +1366,19 @@ I<string>.  The search string which can be a word or phrase
 
 B<iterations> 
 
-I<number>.  The number of iterations that you want the function to search and build cluster on.
+I<number>.  The number of iterations that you want the function to search and 
+build cluster on.
 
 
 B<trace_file>.
 
-I<string>.   The location of the trace file. If a file_name is given, the results are stored in this file
+I<string>.   The location of the trace file. If a file_name is given, the 
+results are stored in this file
 
 =back
 
-returns : Returns a hash which contains the parsed sentences as values and the key being the web URL.
+returns : Returns a hash which contains the parsed sentences as values and the
+key being the web URL.
 
 =cut
 
@@ -1364,7 +1439,9 @@ while( ($Key, $Value) = each(%stop_list) ){
 
 =head2 __PACKAGE__->getPairWordClusters(\%args)
 
-  Purpose:Given two search strings, this function retreive the snippets for each string, and then finds the intersection of words, and then repeats the search with the intersection of words.
+  Purpose:Given two search strings, this function retreive the snippets for 
+each string, and then finds the intersection of words, and then repeats the 
+search with the intersection of words.
 
 Valid arguments are :
 
@@ -1387,17 +1464,20 @@ I<string>.  The search string which can be a word or phrase
 
 B<iterations> 
 
-I<number>.  The number of iterations that you want the function to search and build cluster on.
+I<number>.  The number of iterations that you want the function to search and 
+build cluster on.
 
 =item *
 
 B<trace_file>.
 
-I<string>.   The location of the trace file. If a file_name is given, the results are stored in this file
+I<string>.   The location of the trace file. If a file_name is given, the 
+results are stored in this file
 
 =back
 
-returns : Returns a hash which contains the intersecting words as keys and the values being the frequency of occurence.
+returns : Returns a hash which contains the intersecting words as keys and the
+ values being the frequency of occurence.
 
 =cut
 
@@ -1409,15 +1489,27 @@ sub getPairWordClusters
     my  $searchInfo = shift;
     my  $searchString1 = shift;  
     my  $searchString2 = shift;
+    my  $numResults=shift;
+    my  $cutOff=shift;
     my  $trace_file=shift;
 
+  if(!defined($numResults))
+  {
+      $numResults=10;
+  }
+ if(!defined($cutOff))
+  {
+      $cutOff=1;
+  }
 
     print "i am in word clusters" ;
     #first, doing a search with the given strings, and finding the intersecting words
     #this associative array would contain the word as a key and the frequency of occurence as the
     #value
 
-    %first_intersection=WebService::GoogleHack::getSearchCommonWords($searchInfo, $searchString1, $searchString2, $trace_file);
+    
+%first_intersection=WebService::GoogleHack::getSearchCommonWords($searchInfo, 
+$searchString1, $searchString2, $numResults,$trace_file);
 
     
     @intersection=();
@@ -1443,7 +1535,7 @@ if($Key ne "")
 	#now I am calling this funciton to return the set of words in the snippet 
 	#for each intersecting word
 	
-	%temp=WebService::GoogleHack::getSearchSnippetWords($searchInfo, $intersection[$i], 5, $trace_file);
+	%temp=WebService::GoogleHack::getSearchSnippetWords($searchInfo, $intersection[$i], $numResults, $trace_file);
 
 	#now, again to use Set::Scalar i need to store this stuff in an array
 	#arrays would array0.array1 etc etc.
@@ -1500,11 +1592,11 @@ if($Key ne "")
 		$temp_string="";
 		$temp_string=$e;
 		
-		if($e eq "car")
-{
-    print "\n\n\n Here ";
-    print $cluster{"$temp_string"};
-}
+	#	if($e eq "car")
+#{
+ #   print "\n\n\n Here ";
+ #   print $cluster{"$temp_string"};
+#}
 		$cluster{"$temp_string"}++ if exists $cluster{"$temp_string"};
 		
 #else if the sequence does not in the array, then insert it into the array
@@ -1543,7 +1635,7 @@ $extended_fileContent="\n\n Extended Cluster for $searchString1 & $searchString2
 
 while( ($Key, $Value) = each(%cluster) ){
     
-    if($cluster{"$Key"} > 1)    
+    if($cluster{"$Key"} > $cutOff)    
 {
     $fileContent.="\n$Key, $Value";
 }
@@ -1585,7 +1677,11 @@ if($trace_file ne "")
 
 =head2 __PACKAGE__->getText(\%args)
 
-  Purpose:Given a search string, this function will retreive the resulting URLs from Google, follow those links, and retrieve the text from there.  The function will then clean up the text and store it in a file along with the URL, Date and time of retrieval.The file will be stored under the name of the search string.
+  Purpose:Given a search string, this function will retreive the resulting 
+URLs from Google, follow those links, and retrieve the text from there.  The 
+function will then clean up the text and store it in a file along with the URL,
+ Date and time of retrieval.The file will be stored under the name of the 
+search string.
 
 Valid arguments are :
 
@@ -1601,13 +1697,15 @@ I<string>.  The search string which can be a word or phrase.
 
 B<iterations> 
 
-I<number>.  The number of iterations that you want the function to search and build cluster on.
+I<number>.  The number of iterations that you want the function to search and 
+build cluster on.
 
 =item *
 
 B<path_to_data_directory>.
 
-I<string>.   The location where the file containing the retrived information has to be stored.
+I<string>.   The location where the file containing the retrived information 
+has to be stored.
 
 =back
 
@@ -1678,6 +1776,47 @@ $date=$Month."-".$Day."-".$Year;
     
 }
 
+sub getDateHeader
+{
+
+($Second, $Minute, $Hour, $Day, $Month, $Year, $WeekDay, $DayOfYear, $IsDST) = localtime(time);
+
+$Month = $Month + 1; 
+
+if($Month < 10)
+{
+    $Month = "0" . $Month; 
+}
+
+
+if($Day < 10)
+{
+    $Day = "0" . $Day; 
+}
+
+if($Minute < 10)
+{
+    $Minute = "0" . $Minute; 
+}
+
+if($Hour < 10)
+{
+    $Hour = "0" . $Hour; 
+}
+
+if($Second < 10)
+{
+    $Second = "0" . $Second; 
+}
+
+$Year=$Year+1900;
+
+
+$date=$Month."-".$Day."-".$Year." @ ".$Hour.":".$Minute.":".$Second;
+
+return $date;
+
+}
 
 1;
     
@@ -1693,3 +1832,4 @@ $date=$Month."-".$Day."-".$Year;
 
 
 
+
